finalize_stage

Function finalize_stage 

fn finalize_stage(
    stage: ObjectPlanStage,
    hit_artifacts: &BTreeMap<String, CompiledObjectArtifact>,
) -> ObjectPlanResult
Turn a fingerprint-level stage into a final ObjectPlanResult.

For a fingerprint Hit, attempts to reconstruct the typed object by re-parsing the cached SQL fragments. If any fragment fails to parse the entry is treated as a Miss for fresh compilation.