fn build_cluster_name_map( project: &Project, cluster_suffix: &str, ) -> BTreeMap<String, String>
Build a map from original cluster name to the suffixed cluster name for all clusters referenced by the compiled project.