fn compile_object(
descriptor: ObjectDescriptor,
object_key: String,
fingerprint: String,
profile: &str,
variables: &BTreeMap<String, String>,
profile_set: bool,
file_entries: &BTreeMap<PathBuf, String>,
) -> ObjectCompileResultExpand description
Compile a single object and wrap the result for cache persistence.
Delegates to compile_object_uncached for the actual compilation, then
serializes the result into a CompiledObjectArtifact and packages it
with the object key and fingerprint into an ObjectStateRow ready to
be upserted into the SQLite cache.